@@ -29,7 +29,7 @@
 
 static const GstClockTime _DISCOVER_TIMEOUT = 5 * GST_SECOND;
 
-struct AVMetaReaderGstPrivate {
+struct AvMetaReaderGstPrivate {
 	GMainLoop  *loop;
 	GstDiscoverer *discoverer;
 };
@@ -53,7 +53,7 @@ _get_property (GObject *object,
 }
 
 static GOptionGroup *
-_get_option_group (AVMetaReader *reader)
+_get_option_group (AvMetaReader *reader)
 {
 	static GOptionGroup *option_group = NULL;
 
@@ -71,7 +71,7 @@ _finalize (GObject *self)
 }
 
 static void
-av_meta_reader_gst_class_finalize (AVMetaReaderGstClass *klass)
+av_meta_reader_gst_class_finalize (AvMetaReaderGstClass *klass)
 {
 }
 
@@ -256,15 +256,15 @@ done:
 }
 
 static void
-_on_finished_cb (GstDiscoverer *discoverer, AVMetaReaderGstPrivate *priv)
+_on_finished_cb (GstDiscoverer *discoverer, AvMetaReaderGstPrivate *priv)
 {
 	g_main_loop_quit (priv->loop);
 }
 
 static gboolean
-_read (AVMetaReader *_reader, DmapAvRecord *record, const gchar *path, GError **error)
+_read (AvMetaReader *_reader, DmapAvRecord *record, const gchar *path, GError **error)
 {
-	AVMetaReaderGst *reader = AV_META_READER_GST (_reader);
+	AvMetaReaderGst *reader = AV_META_READER_GST (_reader);
 
 	g_assert (NULL != reader);
 	g_assert (NULL != reader->priv);
@@ -330,7 +330,7 @@ dmapd_module_unload (GTypeModule *module)
 	return TRUE;
 }
 
-static void av_meta_reader_gst_init (AVMetaReaderGst *reader)
+static void av_meta_reader_gst_init (AvMetaReaderGst *reader)
 {
 	reader->priv = AV_META_READER_GST_GET_PRIVATE (reader);
 
@@ -338,10 +338,10 @@ static void av_meta_reader_gst_init (AVMetaReaderGst *reader)
 	reader->priv->discoverer = NULL;
 }
 
-static void av_meta_reader_gst_class_init (AVMetaReaderGstClass *klass)
+static void av_meta_reader_gst_class_init (AvMetaReaderGstClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
-	AVMetaReaderClass *av_meta_reader_class = AV_META_READER_CLASS (klass);
+	AvMetaReaderClass *av_meta_reader_class = AV_META_READER_CLASS (klass);
 
 	gobject_class->set_property = _set_property;
 	gobject_class->get_property = _get_property;
@@ -351,8 +351,8 @@ static void av_meta_reader_gst_class_init (AVMetaReaderGstClass *klass)
 	av_meta_reader_class->get_option_group = _get_option_group;
 }
 
-G_DEFINE_DYNAMIC_TYPE_EXTENDED (AVMetaReaderGst,
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (AvMetaReaderGst,
                                 av_meta_reader_gst,
                                 TYPE_AV_META_READER,
                                 0,
-                                G_ADD_PRIVATE_DYNAMIC (AVMetaReaderGst))
+                                G_ADD_PRIVATE_DYNAMIC (AvMetaReaderGst))
