@@ -30,28 +30,28 @@ G_BEGIN_DECLS
 
 #define TYPE_AV_META_READER_GST          (av_meta_reader_gst_get_type ())
 #define AV_META_READER_GST(o)            (G_TYPE_CHECK_INSTANCE_CAST ((o), \
-                                      TYPE_AV_META_READER_GST, AVMetaReaderGst))
+                                      TYPE_AV_META_READER_GST, AvMetaReaderGst))
 #define AV_META_READER_GST_CLASS(k)      (G_TYPE_CHECK_CLASS_CAST ((k), \
-                                      TYPE_AV_META_READER_GST, AVMetaReaderGstClass))
+                                      TYPE_AV_META_READER_GST, AvMetaReaderGstClass))
 #define IS_AV_META_READER_GST(o)         (G_TYPE_CHECK_INSTANCE_TYPE ((o), \
                                       TYPE_AV_META_READER_GST))
 #define IS_AV_META_READER_GST_CLASS(k)   (G_TYPE_CHECK_CLASS_TYPE ((k), \
                                       TYPE_AV_META_READER_GST_CLASS))
 #define AV_META_READER_GST_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), \
-                                      TYPE_AV_META_READER_GST, AVMetaReaderGstClass))
+                                      TYPE_AV_META_READER_GST, AvMetaReaderGstClass))
 #define AV_META_READER_GST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), \
-                                      TYPE_AV_META_READER_GST, AVMetaReaderGstPrivate))
+                                      TYPE_AV_META_READER_GST, AvMetaReaderGstPrivate))
 
-typedef struct AVMetaReaderGstPrivate AVMetaReaderGstPrivate;
+typedef struct AvMetaReaderGstPrivate AvMetaReaderGstPrivate;
 
 typedef struct {
-        AVMetaReader parent;
-	AVMetaReaderGstPrivate *priv;
-} AVMetaReaderGst;
+        AvMetaReader parent;
+	AvMetaReaderGstPrivate *priv;
+} AvMetaReaderGst;
 
 typedef struct {
-        AVMetaReaderClass parent;
-} AVMetaReaderGstClass;
+        AvMetaReaderClass parent;
+} AvMetaReaderGstClass;
 
 GType       av_meta_reader_gst_get_type      (void);
 
