@@ -28,41 +28,41 @@ G_BEGIN_DECLS
 
 #define TYPE_AV_META_READER          (av_meta_reader_get_type ())
 #define AV_META_READER(o)            (G_TYPE_CHECK_INSTANCE_CAST ((o), \
-                                      TYPE_AV_META_READER, AVMetaReader))
+                                      TYPE_AV_META_READER, AvMetaReader))
 #define AV_META_READER_CLASS(k)      (G_TYPE_CHECK_CLASS_CAST ((k), \
-                                      TYPE_AV_META_READER, AVMetaReaderClass))
+                                      TYPE_AV_META_READER, AvMetaReaderClass))
 #define IS_AV_META_READER(o)         (G_TYPE_CHECK_INSTANCE_TYPE ((o), \
                                       TYPE_AV_META_READER))
 #define IS_AV_META_READER_CLASS(k)   (G_TYPE_CHECK_INSTANCE_TYPE ((k), \
                                       TYPE_AV_META_READER))
 #define AV_META_READER_GET_CLASS(k)  (G_TYPE_INSTANCE_GET_CLASS ((k), \
-                                      TYPE_AV_META_READER, AVMetaReaderClass))
+                                      TYPE_AV_META_READER, AvMetaReaderClass))
 
-typedef struct _AVMetaReader AVMetaReader;
-typedef struct _AVMetaReaderClass AVMetaReaderClass;
+typedef struct _AvMetaReader AvMetaReader;
+typedef struct _AvMetaReaderClass AvMetaReaderClass;
 
-struct _AVMetaReader {
+struct _AvMetaReader {
 	GObject parent;
 };
 
-struct _AVMetaReaderClass {
+struct _AvMetaReaderClass {
         GObjectClass parent;
 
-	gboolean      (*read)		  (AVMetaReader *reader,
+	gboolean      (*read)		  (AvMetaReader *reader,
 					   DmapAvRecord *record,
 					   const gchar *path,
                                            GError **error);
-	GOptionGroup *(*get_option_group) (AVMetaReader *reader);
+	GOptionGroup *(*get_option_group) (AvMetaReader *reader);
 };
 
 GType       av_meta_reader_get_type      (void);
 
-gboolean av_meta_reader_read (AVMetaReader  *reader,
+gboolean av_meta_reader_read (AvMetaReader  *reader,
 			      DmapAvRecord  *record,
 			      const gchar   *path,
                               GError       **error);
 
-GOptionGroup *av_meta_reader_get_option_group (AVMetaReader *reader);
+GOptionGroup *av_meta_reader_get_option_group (AvMetaReader *reader);
 
 G_END_DECLS
 
