@@ -21,8 +21,13 @@
 #ifndef _DB_BUILDER_GDIR_H
 #define _DB_BUILDER_GDIR_H
 
+#include <config.h>
 #include <glib.h>
 
+#ifdef HAVE_CHECK
+#include <check.h>
+#endif
+
 #include "db-builder.h"
 #include "dmapd-dmap-container-record.h"
 #include "dmapd-dmap-container-db.h"
@@ -62,6 +67,10 @@ typedef struct {
 
 GType       db_builder_gdir_get_type      (void);
 
-#endif /* __DB_BUILDER_GDIR */
-
 G_END_DECLS
+
+#ifdef HAVE_CHECK
+Suite *db_test_builder_gdir_suite(void);
+#endif
+
+#endif /* __DB_BUILDER_GDIR */
