@@ -33,10 +33,11 @@ db_builder_class_init (DbBuilderClass *klass)
 
 G_DEFINE_TYPE (DbBuilder, db_builder, G_TYPE_OBJECT)
 
-void
+gboolean
 db_builder_build_db_starting_at (DbBuilder *builder,
-			   const char *dir,
-                           DmapContainerRecord *container_record)
+                                 const char *dir,
+                                 DmapContainerRecord *container_record,
+                                 GError **error)
 {
-	return DB_BUILDER_GET_CLASS (builder)->build_db_starting_at (builder, dir, container_record);
+	return DB_BUILDER_GET_CLASS (builder)->build_db_starting_at (builder, dir, container_record, error);
 }
