@@ -25,7 +25,7 @@
 static DmapdDmapAvRecordFactory *_factory_singleton;
 
 struct DmapdDmapAvRecordFactoryPrivate {
-	AVMetaReader *av_meta_reader;
+	AvMetaReader *av_meta_reader;
 };
 
 enum {
