@@ -28,6 +28,7 @@
 #include <pwd.h>
 #include <grp.h>
 #include <glib.h>
+#include <sys/stat.h>
 #include <libdmapsharing/dmap.h>
 
 #include "dmapd-dmap-container-record.h"
@@ -64,10 +65,10 @@ static char *_protocol_map[] = {
 	 NULL,
 };
 
-/* Consolidate these so they may be passed to callback, etc. */
+/* Consolidates these so they may be passed to callback, etc. */
 typedef struct workers_t {
 	DmapControlShare *dacp_share;
-	AVRender         *av_render;
+	AvRender         *av_render;
 } workers_t;
 
 typedef struct share_def_t {
@@ -78,6 +79,7 @@ typedef struct share_def_t {
 	char        **formats;
 	char         *transcode_mimetype;
 	gboolean      enable_rt_transcode;
+	DbBuilder    *builder;
 	DmapShare    *share;
 } share_def_t;
 
@@ -91,6 +93,7 @@ static gchar  **_picture_formats          = NULL;
 static gchar   *_module_dir               = NULL;
 static gchar   *_config_file              = DEFAULT_CONFIG_FILE;
 static gchar   *_db_dir                   = NULL;
+static gchar   *_run_dir                  = NULL;
 static gchar   *_lockpath                 = NULL;
 static gchar   *_password                 = NULL;
 static gchar   *_pidpath                  = NULL;
@@ -129,6 +132,7 @@ _free_globals(void)
 	g_strfreev(_picture_formats);
 
 	g_free(_db_dir);
+	g_free(_run_dir);
 	g_free(_lockpath);
 	g_free(_password);
 	g_free(_pidpath);
@@ -148,7 +152,7 @@ _strvappend(gchar **vector, char *str)
 	vector = g_new0(gchar *, length + 2);
 	memcpy(vector, old, length * sizeof(gchar *));
 	vector[length] = str;
-	g_strfreev(old);
+	g_free(old); /* Do not free contained strings. */
 	return vector;
 }
 
@@ -183,8 +187,9 @@ static GOptionEntry _entries[] = {
 	{ "lockpath", 'l', 0, G_OPTION_ARG_STRING, &_lockpath, "Path to lockfile", NULL },
 	{ "pidpath", 'i', 0, G_OPTION_ARG_STRING, &_pidpath, "Path to PID file", NULL },
 	{ "db-dir", 'd', 0, G_OPTION_ARG_STRING, &_db_dir, "Media database directory", NULL },
+	{ "run-dir", 'R', 0, G_OPTION_ARG_STRING, &_run_dir, "Runtime directory", NULL },
 	{ "user", 'u', 0, G_OPTION_ARG_STRING, &_user, "User to run as", NULL },
-	{ "_group", 'g', 0, G_OPTION_ARG_STRING, &_group, "Group to run as", NULL },
+	{ "group", 'g', 0, G_OPTION_ARG_STRING, &_group, "Group to run as", NULL },
 	{ "render", 'o', 0, G_OPTION_ARG_NONE, &_enable_render, "Render using AirPlay", NULL },
 	{ "transcode-mimetype", 't', 0, G_OPTION_ARG_STRING, &_transcode_mimetype, "Target MIME type for transcoding", NULL },
 	{ "rt-transcode", 'r', 0, G_OPTION_ARG_NONE, &_enable_rt_transcode, "Perform transcoding in real-time", NULL },
@@ -288,7 +293,7 @@ _daemonize (void)
 	int child, fd;
 	char *pid;
 	ssize_t size;
-	char *lockpath, *pidpath;
+	char *run_dir, *lockpath, *pidpath;
 
 	child = fork ();
 
@@ -304,8 +309,9 @@ _daemonize (void)
 		g_error("Error executing setsid: %s", strerror(errno));
 	}
 
-	if (-1 == chdir (DEFAULT_RUNDIR)) {
-		g_error("Error chdir to %s: %s", DEFAULT_RUNDIR, strerror(errno));
+	run_dir = _run_dir ? _run_dir : DEFAULT_RUNDIR;
+	if (-1 == chdir (run_dir)) {
+		g_error("Error chdir to %s: %s", run_dir, strerror(errno));
 	}
 
 	lockpath = _lockpath ? _lockpath : DEFAULT_LOCKPATH;
@@ -401,7 +407,6 @@ _serve (protocol_id_t protocol,
 	DmapDb *db = NULL;
 	gboolean ok;
 	DmapShare *share = NULL;
-	DbBuilder *builder;
 	DmapContainerDb *container_db = NULL;
 
 	gchar *db_protocol_dir = g_strconcat (_db_dir ? _db_dir : DEFAULT_DBDIR,
@@ -425,19 +430,19 @@ _serve (protocol_id_t protocol,
 	}
 
 	container_db = DMAP_CONTAINER_DB (dmapd_dmap_container_db_new ());
-	builder = DB_BUILDER (util_object_from_module (TYPE_DB_BUILDER,
-	                                          _module_dir,
-	                                         "gdir",
-	                                          NULL));
+	share_def->builder = DB_BUILDER (util_object_from_module (TYPE_DB_BUILDER,
+	                                                          _module_dir,
+	                                                         "gdir",
+	                                                          NULL));
 
-	g_object_set (builder, "db", db, NULL);
+	g_object_set (share_def->builder, "db", db, NULL);
 
 	for (int i = 0; share_def->dirs && share_def->dirs[i]; i++) {
 		if (_enable_dir_containers) {
-			g_object_set (builder, "container-db", container_db, NULL);
+			g_object_set (share_def->builder, "container-db", container_db, NULL);
 		}
 
-		ok = db_builder_build_db_starting_at (builder, share_def->dirs[i], NULL, error);
+		ok = db_builder_build_db_starting_at (share_def->builder, share_def->dirs[i], NULL, error);
 		if (!ok) {
 			goto done;
 		}
@@ -474,7 +479,6 @@ _serve (protocol_id_t protocol,
 	}
 
 done:
-	g_object_unref (builder);
 	g_object_unref (container_db);
 	g_object_unref (db);
 
@@ -548,6 +552,7 @@ _read_keyfile (void)
 		gsize   num_groups;
 
 		_db_dir                = _key_file_s_or_default (keyfile, "General", "Database-Dir", _db_dir);
+		_run_dir               = _key_file_s_or_default (keyfile, "General", "Run-Dir", _run_dir);
 		_user                  = _key_file_s_or_default (keyfile, "General", "User", _user);
 		_group                 = _key_file_s_or_default (keyfile, "General", "Group", _group);
 		_enable_dir_containers = _key_file_b_or_default (keyfile, "General", "Dir-Containers", _enable_dir_containers);
@@ -692,7 +697,7 @@ main (int argc, char *argv[])
 	int exitval = EXIT_SUCCESS;
 	GError *error = NULL;
 	GOptionContext *context;
-	AVMetaReader *av_meta_reader = NULL;
+	AvMetaReader *av_meta_reader = NULL;
 	PhotoMetaReader *photo_meta_reader = NULL;
 
 	workers_t workers = { NULL, NULL };
